// Created on: 1993-01-09
// Created by: CKY / Contract Toubro-Larsen (Arun MENON)
// Copyright (c) 1993-1999 Matra Datavision
// Copyright (c) 1999-2014 OPEN CASCADE SAS
//
// This file is part of Open CASCADE Technology software library.
//
// This library is free software; you can redistribute it and/or modify it under
// the terms of the GNU Lesser General Public License version 2.1 as published
// by the Free Software Foundation, with special exception defined in the file
// OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
// distribution for complete text of the license and disclaimer of any warranty.
//
// Alternatively, this file may be used under the terms of Open CASCADE
// commercial license or contractual agreement.

#include <IGESBasic_HArray1OfHArray1OfInteger.hxx>

#include <Standard_Type.hxx>

#define Handle_TheKey Handle(TColStd_HArray1OfInteger)
#define TheKey TColStd_HArray1OfInteger
#define TheKey_hxx <TColStd_HArray1OfInteger.hxx>
#define Interface_JaggedArray IGESBasic_HArray1OfHArray1OfInteger
#define Interface_JaggedArray_hxx <IGESBasic_HArray1OfHArray1OfInteger.hxx>
#define Handle_Interface_JaggedArray Handle(IGESBasic_HArray1OfHArray1OfInteger)
#include "../Interface/Interface_JaggedArray.gxx"
